@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::MailReset;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.2.2_01';
 
 use Lemonldap::NG::Portal::Simple qw(:all);
 use base qw(Lemonldap::NG::Portal::SharedConf Exporter);
@@ -29,6 +29,8 @@ use POSIX qw(strftime);
 #   - extractMailInfo
 #   - getMailUser
 #   - storeMailSession
+#   - initCaptcha
+#   - checkCaptcha
 #   - sendConfirmationMail
 #   - changePassword
 #   - sendPasswordMail
@@ -50,15 +52,17 @@ sub process {
 
     $self->{error} = $self->_subProcess(
         qw(smtpInit userDBInit passwordDBInit extractMailInfo
-          getMailUser setSessionInfo setMacros setGroups
-          setPersistentSessionInfo setLocalGroups storeMailSession
-          sendConfirmationMail changePassword sendPasswordMail)
+          getMailUser initCaptcha checkCaptcha setSessionInfo
+          setMacros setGroups setPersistentSessionInfo setLocalGroups
+          storeMailSession sendConfirmationMail changePassword sendPasswordMail)
     );
 
     return (
         (
                  $self->{error} <= 0
               or $self->{error} == PE_PASSWORD_OK
+              or $self->{error} == PE_CAPTCHAERROR
+              or $self->{error} == PE_CAPTCHAEMPTY
               or $self->{error} == PE_MAILCONFIRMOK
               or $self->{error} == PE_MAILOK
         ) ? 0 : 1
