@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::_Choice;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.2_01';
 
 ## @apmethod int passwordDBInit()
 # Does nothing
@@ -27,12 +27,4 @@ sub modifyPassword {
     return $self->_choice->try( 'modifyPassword', 2 );
 }
 
-## @apmethod int resetPassword()
-# Does nothing
-# @return Lemonldap::NG::Portal constant
-sub resetPassword {
-    my $self = shift;
-    return $self->_choice->try( 'resetPassword', 2 );
-}
-
 1;
