@@ -12,7 +12,7 @@ use base qw(Lemonldap::NG::Portal::_DBI );
 
 #inherits Lemonldap::NG::Portal::_SMTP
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.2.2_01';
 
 ## @apmethod int passwordDBInit()
 # Load SMTP functions and call DBI authInit()
@@ -41,6 +41,14 @@ sub modifyPassword {
     # Exit if no password change requested
     return PE_OK unless ( $self->{newpassword} );
 
+    # Check if portal require old password
+    if ( $self->{portalRequireOldPassword} ) {
+        unless ( $self->{oldpassword} ) {
+            $self->lmLog( "Portal require old password", 'error' );
+            return PE_PP_MUST_SUPPLY_OLD_PASSWORD;
+        }
+    }
+
     # Verify confirmation password matching
     return PE_PASSWORD_MISMATCH
       unless ( $self->{newpassword} eq $self->{confirmpassword} );
