@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::PasswordDBDemo;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.2.2_01';
 
 ## @apmethod int passwordDBInit()
 # Check the use of AuthDemo
@@ -36,6 +36,14 @@ sub modifyPassword {
     # Exit if no password change requested
     return PE_OK unless ( $self->{newpassword} );
 
+    # Check if portal require old password
+    if ( $self->{portalRequireOldPassword} ) {
+        unless ( $self->{oldpassword} ) {
+            $self->lmLog( "Portal require old password", 'error' );
+            return PE_PP_MUST_SUPPLY_OLD_PASSWORD;
+        }
+    }
+
     # Verify confirmation password matching
     return PE_PASSWORD_MISMATCH
       unless ( $self->{newpassword} eq $self->{confirmpassword} );
