@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::PasswordDBNull;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.2_01';
 
 ## @apmethod int passwordDBInit()
 # Does nothing
@@ -24,11 +24,4 @@ sub modifyPassword {
     PE_OK;
 }
 
-## @apmethod int resetPassword()
-# Does nothing
-# @return Lemonldap::NG::Portal constant
-sub resetPassword {
-    PE_OK;
-}
-
 1;
