@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_LDAP 'ldap';    #link protected ldap
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.2.2_01';
 
 ## @method int userDBInit()
 # Transform ldapGroupAttributeNameSearch in ARRAY ref
@@ -80,7 +80,7 @@ sub search {
         $self->lmLog( 'LDAP Search error: ' . $mesg->error, 'error' );
         return PE_LDAPERROR;
     }
-    unless ( $mesg->count() == 1 ) {
+    if ( $mesg->count() > 1 ) {
         $self->lmLog( 'More than one entry returned by LDAP directory',
             'error' );
         return PE_BADCREDENTIALS;
