@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::_Choice;
 
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.0.2';
+our $VERSION = '1.2.2_01';
 
 ## @cmethod Lemonldap::NG::Portal::_Choice new(Lemonldap::NG::Portal::Simple portal)
 # Constructor
@@ -109,7 +109,7 @@ sub try {
 
     # Default behavior in no choice
     unless ( defined $self->{modules} ) {
-        return PE_FORMEMPTY if ( $sub eq 'extractFormInfo' );
+        return PE_FIRSTACCESS if ( $sub eq 'extractFormInfo' );
         return PE_OK;
     }
 
@@ -177,38 +177,27 @@ sub _buildAuthLoop {
         # Remove it in displayed name
         $name =~ s/^(\d*)?(\s*)?//;
 
+        # Replace also _ by space for a nice display
+        $name =~ s/\_/ /g;
+
         # Find modules associated to authChoice
         my ( $auth, $userDB, $passwordDB ) =
           split( /\|/, $self->{authChoiceModules}->{$_} );
 
-        # What do display
-        # -> login/password form (LDAP, DBI, ...)
-        # -> OpenID form
-        # -> logo with link (ex: CAS, SSL, etc.)
-        my $displayType = {
-            'standardform' => [qw(LDAP DBI Proxy)],
-            'openidform'   => [qw(OpenID)],
-            'logo'         => [qw(CAS Twitter SAML SSL Apache Remote)],
-        };
-
         if ( $auth and $userDB and $passwordDB ) {
 
             # Options to store in the loop
             my $optionsLoop = { name => $name, key => $_, module => $auth };
 
             # Get displayType for this module
+            my $modulePrefix = 'Lemonldap::NG::Portal::';
+            my $authModule   = $modulePrefix . 'Auth' . $auth;
+            $self->loadModule($authModule);
+            my $displayType = &{ $authModule . '::getDisplayType' };
 
-            foreach my $type ( keys %$displayType ) {
-                foreach my $backend ( @{ $displayType->{$type} } ) {
-                    if ( $auth eq $backend ) {
-                        $self->lmLog( "Display type $type for module $auth",
-                            'debug' );
-
-                        $optionsLoop->{$type} = 1;
-                        last;
-                    }
-                }
-            }
+            $self->lmLog( "Display type $displayType for module $auth",
+                'debug' );
+            $optionsLoop->{$displayType} = 1;
 
             # Register item in loop
             push @authLoop, $optionsLoop;
