@@ -10,7 +10,7 @@ use Lemonldap::NG::Portal::Simple;
 use MIME::Base64;
 use SOAP::Lite;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.2_01';
 our $initDone;
 
 BEGIN {
@@ -62,7 +62,7 @@ sub proxyQuery {
     if ( $res->{error} ) {
         $self->_sub( 'userError',
             "Authentication failed for $self->{user} "
-              . $soap->error( 'fr', $res->{error} )->result() );
+              . $soap->error( $res->{error} )->result() );
         return PE_BADCREDENTIALS;
     }
     $self->{_remoteId} = $res->{cookies}->{ $self->{remoteCookieName} }
