@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::_LibAccess;
 require SOAP::Lite;
 use base qw(Lemonldap::NG::Portal::_LibAccess);
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.2.2_01';
 
 ## @method void startSoapServices()
 # Check the URI requested (PATH_INFO environment variable) and launch the
@@ -326,11 +326,8 @@ sub exportedAttr {
         return split /\s+/, $self->{exportedAttr};
     }
     else {
-        my @attributes = (
-            'authenticationLevel', 'groups',
-            'ipAddr',              'xForwardedForAddr',
-            'startTime',           '_utime'
-        );
+        my @attributes =
+          ( 'authenticationLevel', 'groups', 'ipAddr', 'startTime', '_utime' );
         if ( my $exportedAttr = $self->{exportedAttr} ) {
             $exportedAttr =~ s/^\s*\+\s+//;
             @attributes = ( @attributes, split( /\s+/, $exportedAttr ) );
